@@ -3,11 +3,8 @@ from .call import call
 from .decompose import decompose
 from .derivative import diff, gradient, hessian
 from .isconstant import isconstant
-from .monomial import monomial, bindex
 from .divide import poly_divide, poly_divmod, poly_remainder
-from .symbols import symbols
 from .tonumpy import tonumpy
 
-__all__ = ("bindex", "call", "decompose", "diff", "gradient", "hessian",
-           "isconstant", "monomial", "poly_divide", "poly_divmod",
-           "poly_remainder", "symbols", "tonumpy")
+__all__ = ("call", "decompose", "diff", "gradient", "hessian", "isconstant",
+           "poly_divide", "poly_divmod", "poly_remainder", "tonumpy")
